require "import"
import "android.widget.*"
import "android.view.View"
import "android.content.Context"
import "android.content.Intent"
import "android.net.Uri"
import "android.content.ClipboardManager"
import "android.content.ClipData"
import "android.graphics.Typeface"
import "java.io.File"
import "java.net.URLEncoder"
import "android.os.Vibrator" -- Pastikan import ini ada dan benar

function vibrate()
    local vibrator = activity.getSystemService(Context.VIBRATOR_SERVICE)
    if vibrator then
        vibrator.vibrate(20)
    end
end

-- Global references
activity = this
usernameInput = nil
local dlg = nil -- Referensi dialog utama

function openTelegram(url)
    if not url or url == "" then
        service.speak("Tautan tidak valid.")
        return
    end
    service.speak("Membuka Telegram...")
    local intent = Intent(Intent.ACTION_VIEW, Uri.parse(url))
    intent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
    activity.startActivity(intent)
end

function copyLink(url)
    local clipboardManager = activity.getSystemService(Context.CLIPBOARD_SERVICE)
    local clipData = ClipData.newPlainText("Pembuat Tautan Telegram", url)
    clipboardManager.setPrimaryClip(clipData)
    service.speak("Tautan berhasil disalin!")
    vibrate()
end

function shareLink(url)
    local shareIntent = Intent(Intent.ACTION_SEND)
    shareIntent.setType("text/plain")
    shareIntent.putExtra(Intent.EXTRA_TEXT, "Cek profil Telegram ini: " .. url .. "\n\n(Dibuat dengan Pembuat Tautan Telegram)")
    shareIntent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
    activity.startActivity(Intent.createChooser(shareIntent, "Bagikan Tautan"))
    service.speak("Berbagi tautan...")
end

function createTelegramLink()
    local username_text = ""
    if _G.usernameInput then
        username_text = tostring(_G.usernameInput.getText()):gsub("%s+", "")
    end

    if username_text == "" then
        service.speak("Silakan masukkan nama pengguna Telegram!")
        return
    end

    local telegramAppUrl = "tg://resolve?domain=" .. username_text
    local telegramWebUrl = "https://t.me/" .. username_text

    local actionDialog = LuaDialog(activity)
    actionDialog.setTitle("Pilih Tindakan")

    local dialogLayout = {
        LinearLayout,
        orientation = "vertical",
        layout_width = "fill",
        layout_height = "wrap_content",
        padding = "16dp",
        {
            TextView,
            text = "Nama Pengguna: " .. username_text,
            textSize = "18sp",
            layout_gravity = "center_horizontal",
            paddingBottom = "16dp",
            textColor = "#333333",
            typeface = Typeface.create("sans-serif-medium", Typeface.NORMAL)
        },
        {
            Button,
            text = "Buka di Telegram: " .. username_text,
            layout_width = "fill",
            layout_height = "wrap_content",
            layout_marginTop = "12dp",
            background = "#0088CC",
            textColor = "#FFFFFF",
            textSize = "16sp",
            padding = "12dp",
            onClick = function()
                actionDialog.dismiss()
                if dlg then dlg.dismiss() end
                openTelegram(telegramAppUrl)
            end
        },
        {
            Button,
            text = "Salin Tautan",
            layout_width = "fill",
            layout_height = "wrap_content",
            layout_marginTop = "8dp",
            background = "#2196F3",
            textColor = "#FFFFFF",
            textSize = "16sp",
            padding = "12dp",
            onClick = function()
                actionDialog.dismiss()
                copyLink(telegramWebUrl)
            end
        },
        {
            Button,
            text = "Bagikan Tautan",
            layout_width = "fill",
            layout_height = "wrap_content",
            layout_marginTop = "8dp",
            background = "#4CAF50",
            textColor = "#FFFFFF",
            textSize = "16sp",
            padding = "12dp",
            onClick = function()
                actionDialog.dismiss()
                if dlg then dlg.dismiss() end
                shareLink(telegramWebUrl)
            end
        }
    }
    actionDialog.setView(loadlayout(dialogLayout))

    actionDialog.setButton("Tutup", function()
        actionDialog.dismiss()
    end)
    actionDialog.show()
end

function createMainDialog()
    local current_username_text = ""
    if _G.usernameInput then
        current_username_text = tostring(_G.usernameInput.getText())
    end

    if dlg then
        dlg.dismiss()
    end

    local main_layout_definition = {
        ScrollView,
        layout_width = "fill",
        layout_height = "fill",
        {
            LinearLayout,
            orientation = "vertical",
            layout_width = "fill",
            layout_height = "wrap_content",
            padding = "16dp",
            gravity = "center_horizontal",
            {
                Button,
                text = "About",
                layout_width = "match",
                layout_height = "wrap_content",
                layout_margin = "16dp",
                onClick = function()
                    dev()
                    vibrate()
                end
            },
            {
                EditText,
                id = "usernameInput",
                hint = "Masukkan Nama Pengguna Telegram (tanpa @)",
                layout_width = "fill",
                layout_height = "wrap_content",
                padding = "12dp",
                inputType = "textNoSuggestions|textUri",
                background = "#EEEEEE",
                textColor = "#333333",
                hintTextColor = "#9E9E9E"
            },
            {
                Button,
                id = "createButton",
                text = "Buat",
                layout_width = "fill",
                layout_height = "wrap_content",
                layout_marginTop = "24dp",
                background = "#007BFF",
                textColor = "#FFFFFF",
                textSize = "18sp",
                padding = "14dp",
                onClick = function()
                    createTelegramLink()
                end
            }
        }
    }

    function dev()
        local aboutDlg
        local aboutLayout = {
            ScrollView,
            layout_width = "fill",
            layout_height = "fill",
            backgroundColor = 0xFF121212,
            {
                LinearLayout,
                orientation = "vertical",
                layout_width = "fill",
                layout_height = "wrap",
                padding = "16dp",
                {
                    TextView,
                    text = "Bergabung ke saluran saya untuk mendapatkan alat plugin Jieshuo lainnya.\n\nRequest, report, dll tentang ekstensi. Silakan hubungi saya",
                    layout_width = "fill",
                    layout_height = "wrap_content",
                    textSize = "20sp",
                    textColor = 0xFFFFFFFF,
                    gravity = "center",
                    backgroundColor = 0xFF6200EE,
                    padding = "12dp"
                },
                {
                    Button,
                    text = "Hubungi Pengembang",
                    layout_width = "fill",
                    layout_height = "wrap",
                    backgroundColor = 0xFF03DAC5,
                    textColor = 0xFF000000,
                    padding = "12dp",
                    onClick = function()
                        vibrate()
                        service.speak("Membuka Telegram...")
                        pcall(function()
                            service.startActivity(Intent(Intent.ACTION_VIEW, Uri.parse("tg://resolve?domain=jibomico")))
                        end)
                        aboutDlg.dismiss()
                        if dlg then dlg.dismiss() end
                    end
                },
                {
                    Button,
                    text = "Bergabung ke saluran Telegram",
                    layout_width = "fill",
                    layout_height = "wrap",
                    backgroundColor = 0xFFBB86FC,
                    textColor = "#FFFFFF",
                    padding = "12dp",
                    onClick = function()
                        vibrate()
                        service.speak("Membuka saluran Telegram...")
                        pcall(function()
                            service.startActivity(Intent(Intent.ACTION_VIEW, Uri.parse("tg://resolve?domain=jieshuojm")))
                        end)
                        aboutDlg.dismiss()
                        if dlg then dlg.dismiss() end
                    end
                },
                {
                    Button,
                    text = "Bergabung ke grup WhatsApp",
                    layout_width = "fill",
                    layout_height = "wrap",
                    backgroundColor = "#4CAF50",
                    textColor = "#FFFFFF",
                    padding = "12dp",
                    onClick = function()
                        vibrate()
                        service.speak("Membuka grup WhatsApp...")
                        pcall(function()
                            service.startActivity(Intent(Intent.ACTION_VIEW, Uri.parse("https://chat.whatsapp.com/EXsCeLRcy9I3njvaqeIn7x")))
                        end)
                        aboutDlg.dismiss()
                        if dlg then dlg.dismiss() end
                    end
                }
            }
        }

        aboutDlg = LuaDialog(activity)
        aboutDlg.setTitle("Developed by Jm")
        aboutDlg.setView(loadlayout(aboutLayout))
        aboutDlg.setButton("Oke", function()
            aboutDlg.dismiss()
            vibrate()
        end)
        aboutDlg.show()
    end

    dlg = LuaDialog(activity)
    dlg.setTitle("Pembuat Tautan Telegram")
    local loaded_root_view = loadlayout(main_layout_definition)
    dlg.setView(loaded_root_view)

    usernameInput = _G.usernameInput

    if usernameInput then
        usernameInput.setText(current_username_text)
    end

    dlg.setButton("Tutup", function()
        dlg.dismiss()
    end)
    dlg.show()
end
createMainDialog()
